import type { EncryptedMessage, WalletConfig, WalletCreateKeyOptions, DidConfig, DidInfo, WalletSignOptions, UnpackedMessageContext, WalletVerifyOptions, Wallet, WalletExportImportConfig, WalletConfigRekey } from '@aries-framework/core';
import type { Session } from '@hyperledger/aries-askar-shared';
import { Buffer, Logger, Key, SigningProviderRegistry, FileSystem } from '@aries-framework/core';
import { Store } from '@hyperledger/aries-askar-shared';
export declare class AskarWallet implements Wallet {
    private walletConfig?;
    private _session?;
    private _store?;
    private logger;
    private fileSystem;
    private signingKeyProviderRegistry;
    private publicDidInfo;
    constructor(logger: Logger, fileSystem: FileSystem, signingKeyProviderRegistry: SigningProviderRegistry);
    get isProvisioned(): boolean;
    get isInitialized(): boolean;
    get publicDid(): DidInfo | undefined;
    get store(): Store;
    get session(): Session;
    get masterSecretId(): string;
    /**
     * Dispose method is called when an agent context is disposed.
     */
    dispose(): Promise<void>;
    /**
     * @throws {WalletDuplicateError} if the wallet already exists
     * @throws {WalletError} if another error occurs
     */
    create(walletConfig: WalletConfig): Promise<void>;
    /**
     * @throws {WalletDuplicateError} if the wallet already exists
     * @throws {WalletError} if another error occurs
     */
    createAndOpen(walletConfig: WalletConfig): Promise<void>;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    open(walletConfig: WalletConfig): Promise<void>;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    rotateKey(walletConfig: WalletConfigRekey): Promise<void>;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    private _open;
    /**
     * @throws {WalletNotFoundError} if the wallet does not exist
     * @throws {WalletError} if another error occurs
     */
    delete(): Promise<void>;
    export(exportConfig: WalletExportImportConfig): Promise<void>;
    import(walletConfig: WalletConfig, importConfig: WalletExportImportConfig): Promise<void>;
    /**
     * @throws {WalletError} if the wallet is already closed or another error occurs
     */
    close(): Promise<void>;
    initPublicDid(didConfig: DidConfig): Promise<void>;
    /**
     * Create a key with an optional seed and keyType.
     * The keypair is also automatically stored in the wallet afterwards
     *
     * @param privateKey Buffer Optional privateKey for creating a key
     * @param seed string Optional seed for creating a key
     * @param keyType KeyType the type of key that should be created
     *
     * @returns a Key instance with a publicKeyBase58
     *
     * @throws {WalletError} When an unsupported keytype is requested
     * @throws {WalletError} When the key could not be created
     */
    createKey({ seed, privateKey, keyType }: WalletCreateKeyOptions): Promise<Key>;
    /**
     * sign a Buffer with an instance of a Key class
     *
     * @param data Buffer The data that needs to be signed
     * @param key Key The key that is used to sign the data
     *
     * @returns A signature for the data
     */
    sign({ data, key }: WalletSignOptions): Promise<Buffer>;
    /**
     * Verify the signature with the data and the used key
     *
     * @param data Buffer The data that has to be confirmed to be signed
     * @param key Key The key that was used in the signing process
     * @param signature Buffer The signature that was created by the signing process
     *
     * @returns A boolean whether the signature was created with the supplied data and key
     *
     * @throws {WalletError} When it could not do the verification
     * @throws {WalletError} When an unsupported keytype is used
     */
    verify({ data, key, signature }: WalletVerifyOptions): Promise<boolean>;
    /**
     * Pack a message using DIDComm V1 algorithm
     *
     * @param payload message to send
     * @param recipientKeys array containing recipient keys in base58
     * @param senderVerkey sender key in base58
     * @returns JWE Envelope to send
     */
    pack(payload: Record<string, unknown>, recipientKeys: string[], senderVerkey?: string): Promise<EncryptedMessage>;
    /**
     * Unpacks a JWE Envelope coded using DIDComm V1 algorithm
     *
     * @param messagePackage JWE Envelope
     * @returns UnpackedMessageContext with plain text message, sender key and recipient key
     */
    unpack(messagePackage: EncryptedMessage): Promise<UnpackedMessageContext>;
    generateNonce(): Promise<string>;
    generateWalletKey(): Promise<string>;
    private getAskarWalletConfig;
    private retrieveKeyPair;
    private storeKeyPair;
}
